@@ -28,7 +28,6 @@ import ctypes
 try:
     import pycuda.driver as cuda
     # https://documen.tician.de/pycuda/driver.html
-    import pycuda.autoinit
 except ImportError as e:
     print(
         f'pycuda not installed, or import failed. inference on trt will be disabled. error: {e}')
@@ -400,11 +399,8 @@ def load_torchtrt_plugins():
         osp.expanduser(
             "~"), "torchtrt_plugins/build/lib/libtorchtrt_plugins.so"
     )
-    lib_path2 = '/usr/local/lib/libtorchtrt_plugins.so'
     if os.path.exists(lib_path):
         ctypes.CDLL(lib_path)
-    elif os.path.exists(lib_path2):
-        ctypes.CDLL(lib_path2)
     else:
         logger.warning(f"{lib_path} not found.")
 
@@ -506,7 +502,7 @@ def build_engine_onnx_v3(
         return build_engine(max_batch_size, save_engine)
 
 
-def check_engine(engine, input_shape=(608, 608), do_print=False):
+def check_engine(engine, input_shape=(608, 608), print=False):
     tensor_names_shape_dict = {}
     for binding in engine:
         dims = engine.get_binding_shape(binding)
@@ -524,7 +520,7 @@ def check_engine(engine, input_shape=(608, 608), do_print=False):
                 "dtype": dtype,
                 "is_input": True,
             }
-            if do_print:
+            if print:
                 print(f"[{binding}]: {dims}, {dtype.name}, [INPUT]")
         else:
             tensor_names_shape_dict[binding] = {
@@ -532,6 +528,6 @@ def check_engine(engine, input_shape=(608, 608), do_print=False):
                 "dtype": dtype,
                 "is_input": False,
             }
-            if do_print:
+            if print:
                 print(f"[{binding}]: {dims}, {dtype.name}, [OUTPUT]")
     return tensor_names_shape_dict
